==> webkit2gtk_2.42.2.orig.tar.xz: webkitgtk-2.42.2/Source/WebCore/html/canvas/EXTDisjointTimerQuery.h <==
/*
 * Copyright 2023 The Chromium Authors. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "WebGLExtension.h"

namespace WebCore {

class EXTDisjointTimerQuery final : public WebGLExtension {
    WTF_MAKE_ISO_ALLOCATED(EXTDisjointTimerQuery);
public:
    explicit EXTDisjointTimerQuery(WebGLRenderingContextBase&);
    virtual ~EXTDisjointTimerQuery();

    ExtensionName getName() const override;

    static bool supported(GraphicsContextGL&);

    RefPtr<WebGLTimerQueryEXT> createQueryEXT();
    void deleteQueryEXT(WebGLTimerQueryEXT*);
    GCGLboolean isQueryEXT(WebGLTimerQueryEXT*);
    void beginQueryEXT(GCGLenum target, WebGLTimerQueryEXT&);
    void endQueryEXT(GCGLenum target);
    void queryCounterEXT(WebGLTimerQueryEXT&, GCGLenum target);
    WebGLAny getQueryEXT(GCGLenum target, GCGLenum pname);
    WebGLAny getQueryObjectEXT(WebGLTimerQueryEXT&, GCGLenum pname);
};

} // namespace WebCore

==> webkit2gtk_2.44.2.orig.tar.xz: webkitgtk-2.44.2/Source/WebCore/html/canvas/EXTDisjointTimerQuery.h <==
/*
 * Copyright 2023 The Chromium Authors. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1.  Redistributions of source code must retain the above copyright
 *     notice, this list of conditions and the following disclaimer.
 * 2.  Redistributions in binary form must reproduce the above copyright
 *     notice, this list of conditions and the following disclaimer in the
 *     documentation and/or other materials provided with the distribution.
 *
 * THIS SOFTWARE IS PROVIDED BY APPLE AND ITS CONTRIBUTORS "AS IS" AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL APPLE OR ITS CONTRIBUTORS BE LIABLE FOR ANY
 * DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 * ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#pragma once

#include "WebGLExtension.h"
#include "WebGLRenderingContext.h"
#include <wtf/IsoMalloc.h>
#include <wtf/Noncopyable.h>

namespace WebCore {

class WebGLTimerQueryEXT;

class EXTDisjointTimerQuery final : public WebGLExtension<WebGLRenderingContext> {
    WTF_MAKE_ISO_ALLOCATED(EXTDisjointTimerQuery);
    WTF_MAKE_NONCOPYABLE(EXTDisjointTimerQuery);
public:
    explicit EXTDisjointTimerQuery(WebGLRenderingContext&);
    ~EXTDisjointTimerQuery();

    static bool supported(GraphicsContextGL&);

    RefPtr<WebGLTimerQueryEXT> createQueryEXT();
    void deleteQueryEXT(WebGLTimerQueryEXT*);
    GCGLboolean isQueryEXT(WebGLTimerQueryEXT*);
    void beginQueryEXT(GCGLenum target, WebGLTimerQueryEXT&);
    void endQueryEXT(GCGLenum target);
    void queryCounterEXT(WebGLTimerQueryEXT&, GCGLenum target);
    WebGLAny getQueryEXT(GCGLenum target, GCGLenum pname);
    WebGLAny getQueryObjectEXT(WebGLTimerQueryEXT&, GCGLenum pname);
};

} // namespace WebCore
